from unittest import TestCase
from lr1110evk.SerialExchange import (
    CommandConfigure,
    WifiMode,
    WifiEnableMode,
    GnssOption,
    GnssCaptureMode,
    GnssAntennaSelection,
    GnssConstellation,
)
from lr1110evk.BaseTypes import WifiChannels


class CommandConfigureTestCase(TestCase):
    def test_channels_bit_mask_generation(self):
        channel_names = ["CHANNEL_1", "CHANNEL_6", "CHANNEL_11"]
        channels = [WifiChannels.get_channel_from_name(name) for name in channel_names]
        bit_mask = CommandConfigure.channel_list_to_bit_mask(channels)
        self.assertEqual(bit_mask, b"\x21\x04")

    def test_types_bit_mask_generation(self):
        type_names = ["TYPE_B"]
        bit_mask = CommandConfigure.type_list_to_bit_mask(type_names)
        self.assertEqual(bit_mask, b"\x01")

    def test_command_configure_build(self):
        channel_names = ["CHANNEL_1", "CHANNEL_6", "CHANNEL_11"]
        channels = [WifiChannels.get_channel_from_name(name) for name in channel_names]

        command = CommandConfigure()
        command.wifi_channels = channels
        command.wifi_types = ["TYPE_B"]
        command.wifi_enable_mode = WifiEnableMode.wifi_scan
        command.wifi_nbr_retrials = 1
        command.wifi_max_results_per_scan = 5
        command.wifi_timeout = 110
        command.wifi_mode = WifiMode.beacon_only
        command.gnss_autonomous_option = GnssOption.best_effort
        command.gnss_autonomous_enable = True
        command.gnss_autonomous_capture_mode = GnssCaptureMode.single
        command.gnss_autonomous_nb_satellite = 0
        command.gnss_autonomous_antenna_selection = GnssAntennaSelection.no_selection
        command.gnss_autonomous_constellation_mask = GnssConstellation.gps.value
        command.gnss_assisted_enable = False
        command.gnss_assisted_option = GnssOption.default
        command.gnss_assisted_capture_mode = GnssCaptureMode.single
        command.gnss_assisted_nb_satellite = 0
        command.gnss_assisted_antenna_selection = GnssAntennaSelection.select_antenna_2
        command.gnss_assisted_constellation_mask = GnssConstellation.gps.value
        command.gnss_assisted_delay_between_capture_seconds = 30
        command_bytes = command.convert_to_bytes()
        print(command_bytes)
        expected_command_bytes = b"\x02\x00\x15\x00\x01!\x04\x01\x01\x05n\x00\x01\x01\x01\x00\x00\x00\x01\x00\x00\x00\x00\x02\x01"
        self.assertEqual(command_bytes, expected_command_bytes)
