from unittest import TestCase
from lr1110evk.Job.JobReader import JobReader
from lr1110evk.Job.JobJsonValidator import JobValidator
from jsonschema.exceptions import ValidationError
from parameterized import parameterized


def get_assets_location(filename_in_assets):
    import os

    dir_path = os.path.dirname(os.path.realpath(__file__))
    asset_path_relative_to_here = "../lr1110evk/assets"
    asset_path_absolute = os.path.join(dir_path, asset_path_relative_to_here)
    asset_file_path = os.path.join(asset_path_absolute, filename_in_assets)
    return asset_file_path


class JobReaderTestCase(TestCase):
    @parameterized.expand([("jobs.json",), ("job_drive_test_gnss_single.json",)])
    def test_read(self, asset_filename):
        # asset_filename = 'jobs.json'
        asset_file_path = get_assets_location(asset_filename)
        JobValidator.validate_job_json_file(asset_file_path)
        job_reader = JobReader()
        job_reader.read_from_file(asset_file_path)

    def test_validate_json_stream(self):
        correct_job = {
            "infinite_loops": True,
            "jobs": [
                {
                    "name": "WiFi Scan",
                    "n_iterations": 1,
                    "reset_before_job_start": False,
                    "wifi_channels": ["CHANNEL_1", "CHANNEL_6", "CHANNEL_11"],
                    "wifi_types": ["TYPE_B"],
                    "wifi_nbr_retrial": 10,
                    "wifi_max_result_per_scan": 5,
                    "wifi_timeout": 110000,
                    "wifi_mode": "beacon_and_packet",
                    "wifi_api": "country_code",
                }
            ],
        }
        JobValidator.validate_job_json_stream(correct_job)
        self.assertTrue(True)

    def test_validate_erroneous_job_stream(self):
        correct_job = {
            "infinite_loops": True,
            "jobs": [
                {
                    "name": "WiFi Scan",
                    "n_iterations": "ERRONEOUS VALUE FORMAT",
                    "reset_before_job_start": False,
                    "wifi_channels": ["CHANNEL_1", "CHANNEL_6", "CHANNEL_11"],
                    "wifi_types": ["TYPE_B"],
                    "wifi_nbr_retrial": 10,
                    "wifi_max_result_per_scan": 5,
                    "wifi_timeout": 110000,
                    "wifi_mode": "beacon_and_packet",
                }
            ],
        }
        with self.assertRaises(ValidationError):
            JobValidator.validate_job_json_stream(correct_job)
